//
//  ContentView.swift
//  MyToDos
//
//  Created by Stewart Lynch on 2021-04-07.
//

import SwiftUI

struct ContentView: View {
    @EnvironmentObject var dataStore: DataStore
    @FocusState private var focusedField: Bool?
    var body: some View {
        NavigationView {
            List() {
                ForEach($dataStore.toDos) { $toDo in
                    TextField(toDo.name, text: $toDo.name)
                            .font(.title3)
                            .foregroundColor(toDo.completed ? .green : Color(.label))
                            .focused($focusedField, equals: true)
                            .overlay(
                            Rectangle()
                                .fill(Color.green)
                                .frame(height: 1)
                                .opacity(toDo.completed ? 1 : 0)
                            )
                            .onSubmit {
                                dataStore.updateToDo(toDo)
                            }
                    .swipeActions {
                        Button(role: .destructive) {
                            withAnimation {
                                dataStore.deleteToDo(toDo)
                            }
                        } label: {
                            Label("Delete", systemImage: "trash")
                        }
                    }
                    .swipeActions(edge: .leading) {
                        Button {
                            toDo.completed.toggle()
                            dataStore.updateToDo(toDo)
                        } label: {
                            Text(toDo.completed ? "Remove Completion" : "Completed")
                        }.tint(.teal)
                    }
                }
            }
            .listStyle(.insetGrouped)
            .navigationBarTitle("My ToDos")
            .navigationBarItems(
                trailing:
                    Button {
                        dataStore.newToDo()
                    } label: {
                        Image(systemName: "plus.circle.fill")
                    }
            )
        }.task {
            if FileManager().docExist(named: fileName){
                dataStore.loadToDosThrows()
            }
        }
        .alert("File Error",
               isPresented: $dataStore.showErrorAlert,
               presenting: dataStore.appError) { appError in
            appError.button
        } message: { appError in
            Text(appError.message)
        }
        .toolbar {
            ToolbarItemGroup(placement: .keyboard) {
                HStack {
                    Spacer()
                    Button {
                        focusedField = nil
                    } label: {
                        Image(systemName: "keyboard.chevron.compact.down")
                    }
                }
            }
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
            .environmentObject(DataStore())
    }
}
